#!/bin/sh

: ${BINDIR?"Please run Tivoli setup script to set BINDIR first"}
: ${INTERP?"Please run Tivoli setup script to set INTERP first"}

if test "$INTERP" = "w32-ix86"
then
	EXE=.exe
else
	EXE=
fi

image_report=$BINDIR/TAS/INSTALL/image_report
sapack=$BINDIR/TAS/INSTALL/sapack$EXE
out=zzmani.out

usage () {
	echo "Usage: `basename $0` [ -c patchdir ]"
}

case $# in
0)
	PATCHDIR=.
	;;
2)
	if test "$1" = "-c" -a ! -w $2
	then
		echo Cannot open directory: $PATCHDIR
		echo Exiting.
		exit 6
	fi
	PATCHDIR=$2
	;;
*)
	usage
	exit 7
	;;
esac

dirname () {
	expr X$1 : 'X\(\/\)[^/]*$' \| X$1 : X'\(.*\)\/[^/]*$' \| .
}

if test ! -w .
then
	echo Unable to write to current directory
	echo Exiting
	exit 3
fi

if test ! -f $image_report
then
	echo Unable to execute $image_report
	echo Exiting.
	exit 1
fi

if test ! -x $sapack
then
	echo Unable to execute $sapack
	echo Exiting.
	exit 2
fi

filepack=`$image_report -a $INTERP -c $PATCHDIR | fgrep FILE | awk '{print $1}' -`
if test -z "$filepack"
then
	echo "Unable to determine file pack"
	echo "Make sure patch is extracted in directory: \"$PATCHDIR\"" or use -c
	usage
	echo Exiting
	exit 9
fi

# doesn't work on nt
#binary=`$image_report -a $INTERP -f -c $PATCHDIR|awk '{ if (NF == 9) { file = $9; mode = $1 } }
#	 END  { print mode, file }' -`
#mode=`echo $binary | awk '{ print $1 }' -`
#binary=`echo $binary | awk '{ print $2 }' -`
#
# nt work around
mode=100755
binary=TMF/LCF/ep_mgr$EXE

$sapack -u $PATCHDIR/$filepack 2>$out

cleanup () {
	rm -f $binary
	dir=`dirname $binary`
	while test "$dir" != "."
	do
		rmdir $dir
		dir=`dirname $dir`
	done
	rm -f $out
}

if test -f $BINDIR/$binary -a ! -w $BINDIR/$binary
then
	echo "Unable to overwrite $BINDIR/$binary, permission denied."
	cleanup
	echo Exiting.
	exit 8
fi

if test ! -f $binary
then
	echo $sapack failed.
	echo Exiting.
	exit 4
fi

cp $binary $BINDIR/$binary || \
	{ echo "Unable to copy $binary to $BINDIR" && cleanup && exit 5 }
chmod $mode $BINDIR/$binary 2>> $out || \
	{ echo "Unable to chmod $BINDIR/$binary to $mode" && cleanup && exit 10 }

cleanup

echo Successfully installed $BINDIR/$binary
echo Be sure to followup with the normal patch installation procedure.
echo Done.
exit 0
